@@ -78,7 +78,9 @@ def date_option_to_datetime(today: datetime, string: str) -> datetime:
     """
 
     # Try to determine the string's format
-    date_seconds_match = re.search(r"^\d{4}-[01]\d-[0123]\d_[012]\d:[0-5]\d:[0-5]\d", string)
+    date_seconds_match = re.search(
+        r"^\d{4}-[01]\d-[0123]\d_[012]\d:[0-5]\d:[0-5]\d", string
+    )
     if date_seconds_match is not None:
         # Strings seems to be in YYYY-mm-DD HH:MM:SS format
         return datetime.strptime(string, "%Y-%m-%d_%H:%M:%S")
@@ -108,4 +110,4 @@ def date_option_to_datetime(today: datetime, string: str) -> datetime:
         else:
             return today.replace(minute=minute)
 
-    raise ValueError("`string` is neither in XX:MM, HH:MM nor YYYY-mm-DD HH:MM format!")
\ No newline at end of file
+    raise ValueError("`string` is neither in XX:MM, HH:MM nor YYYY-mm-DD HH:MM format!")
